==> wechat-facade-1.0.2-20190425.061456-34-sources.jar: com/bizvane/wechatfacade/models/vo/WxMiniprgmReleaseVO.java <==
package com.bizvane.wechatfacade.models.vo;

import com.bizvane.wechatfacade.models.po.WxMiniprgmRelease;

/**
 * 小程序发布表
 * Created by yunjie.tian on 2018/9/19.
 */
public class WxMiniprgmReleaseVO extends WxMiniprgmRelease {

    @io.swagger.annotations.ApiModelProperty(value = "主键id",name = "sysBrandId", required = false,example = "")
    private Long sysBrandId;

    @io.swagger.annotations.ApiModelProperty(value = "主键id",name = "brandCode", required = false,example = "")
    private String brandCode;

    @io.swagger.annotations.ApiModelProperty(value = "主键id",name = "nickName", required = false,example = "")
    private String nickName;

    @io.swagger.annotations.ApiModelProperty(value = "主键id",name = "appid", required = false,example = "")
    private String appid;

    @io.swagger.annotations.ApiModelProperty(value = "品牌名",name = "brandName", required = false,example = "")
    private String brandName;

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getBrandCode() {
        return brandCode;
    }

    public void setBrandCode(String brandCode) {
        this.brandCode = brandCode;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getAppid() {
        return appid;
    }

    public void setAppid(String appid) {
        this.appid = appid;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }
}

==> wechat-facade-2.0.2-20200526.035714-3-sources.jar: com/bizvane/wechatfacade/models/vo/WxMiniprgmReleaseVO.java <==
package com.bizvane.wechatfacade.models.vo;

import com.bizvane.wechatfacade.models.po.WxMiniprgmRelease;

/**
 * 小程序发布表
 * Created by yunjie.tian on 2018/9/19.
 */
public class WxMiniprgmReleaseVO extends WxMiniprgmRelease {

    @io.swagger.annotations.ApiModelProperty(value = "主键id",name = "sysBrandId", required = false,example = "")
    private Long sysBrandId;

    @io.swagger.annotations.ApiModelProperty(value = "主键id",name = "brandCode", required = false,example = "")
    private String brandCode;

    @io.swagger.annotations.ApiModelProperty(value = "主键id",name = "nickName", required = false,example = "")
    private String nickName;

    @io.swagger.annotations.ApiModelProperty(value = "主键id",name = "appid", required = false,example = "")
    private String appid;

    @io.swagger.annotations.ApiModelProperty(value = "品牌名",name = "brandName", required = false,example = "")
    private String brandName;

    @io.swagger.annotations.ApiModelProperty(value = "品牌名",name = "brandName", required = false,example = "")
    private String companyName;

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getBrandCode() {
        return brandCode;
    }

    public void setBrandCode(String brandCode) {
        this.brandCode = brandCode;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getAppid() {
        return appid;
    }

    public void setAppid(String appid) {
        this.appid = appid;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }
}
